<?php

declare(strict_types=1);

namespace mirzaev\parser_from_interneturok\models\telegram;

// Files of the project
use mirzaev\parser_from_interneturok\models\core,
	mirzaev\parser_from_interneturok\models\enumerations\subject,
	mirzaev\parser_from_interneturok\models\interneturok;

// Framework for Telegram
use Zanzara\Context as context,
	Zanzara\Telegram\Type\Message as message;

/**
 * Telegram commands
 *
 * @package mirzaev\parser_from_interneturok\models\telegram
 *
 * @license http://www.wtfpl.net/ Do What The Fuck You Want To Public License
 * @author Arsen Mirzaev Tatyano-Muradovich <arsen@mirzaev.sexy>
 */
final class commands extends core
{
	/**
	 * Menu
	 *
	 * Responce for the commands: "/start", '/menu'
	 *
	 * @param context $context Request data from Telegram
	 *
	 * @return void
	 */
	public static function menu(context $context): void
	{
		// Initializing amount of accounts
		$rows = interneturok::amount();

		// Sending the message
		$context->sendMessage(
			<<<TXT
			🗂 *Выбери предмет*

			*Количество аккаунтов:* $rows
			TXT,
			[
				'reply_markup' => [
					'inline_keyboard' => [
						[
							[
								'text' => subject::mathematics->value,
								'callback_data' => subject::mathematics->name
							],
							[
								'text' => subject::algebra->value,
								'callback_data' => subject::algebra->name
							],
							[
								'text' => subject::geometry->value,
								'callback_data' => subject::geometry->name
							]
						],
						[
							[
								'text' => subject::probability->value,
								'callback_data' => subject::probability->name
							],
							[
								'text' => subject::informatics->value,
								'callback_data' => subject::informatics->name
							]
						],
						[
							[
								'text' => subject::physics->value,
								'callback_data' => subject::physics->name
							],
							[
								'text' => subject::chemistry->value,
								'callback_data' => subject::chemistry->name
							],
							[
								'text' => subject::biology->value,
								'callback_data' => subject::biology->name
							]
						],
						[
							[
								'text' => subject::geography->value,
								'callback_data' => subject::geography->name
							],
							[
								'text' => subject::history->value,
								'callback_data' => subject::history->name
							],
							[
								'text' => subject::social->value,
								'callback_data' => subject::social->name
							],
							[
								'text' => subject::literature->value,
								'callback_data' => subject::literature->name
							]
						],
						[
							[
								'text' => subject::art->value,
								'callback_data' => subject::art->name
							],
							[
								'text' => subject::music->value,
								'callback_data' => subject::music->name
							],
							[
								'text' => subject::safety->value,
								'callback_data' => subject::safety->name
							],
							[
								'text' => subject::labor->value,
								'callback_data' => subject::labor->name
							],
						],
						[
							[
								'text' => subject::project->value,
								'callback_data' => subject::project->name
							]
						],
						[
							[
								'text' => subject::english->value,
								'callback_data' => subject::english->name
							],
							[
								'text' => subject::russian->value,
								'callback_data' => subject::russian->name
							],
							[
								'text' => subject::german->value,
								'callback_data' => subject::german->name
							],
							[
								'text' => subject::china->value,
								'callback_data' => subject::china->name
							]
						],
						[
							[
								'text' => subject::odnknr->value,
								'callback_data' => subject::odnknr->name
							],
							[
								'text' => subject::obzr->value,
								'callback_data' => subject::obzr->name
							],
							[
								'text' => subject::sport->value,
								'callback_data' => subject::sport->name
							]
						],
					],
					'disable_notification' => true,
					'remove_keyboard' => true
				],
			]
		)->then(function (message $message) use ($context) {
			// Sended the message
		});
	}
}
